Package: fastR2
Type: Package
Title: Foundations and Applications of Statistics Using R (2nd Edition)
Version: 1.2.5
Authors@R: person(given = "Randall", family = "Pruim", role = c("aut", "cre"), 
    email = "rpruim@calvin.edu")
Description: Data sets and utilities to accompany the second edition of
    "Foundations and Applications of Statistics: an Introduction
    using R" (R Pruim, published by AMS, 2017), a text covering
    topics from probability and mathematical statistics at an advanced
    undergraduate level.  R is integrated throughout, and access to all
    the R code in the book is provided via the snippet() function.
License: GPL (>= 2)
Depends: R (>= 3.0.0), mosaic (>= 1.3.0)
Imports: maxLik, numDeriv, dplyr, ggplot2 (>= 3.0.0), lattice,
        miscTools
Suggests: ggformula, mosaicCalc, tidyr, readr, MASS, faraway, Hmisc,
        DAAG, multcomp, vcd, car, alr4, corrgram, BradleyTerry2,
        cubature, knitr, mosaicData, rmarkdown
VignetteBuilder: knitr
LazyLoad: yes
LazyData: yes
RoxygenNote: 7.3.2
Encoding: UTF-8
URL: https://github.com/rpruim/fastR2, http://rpruim.github.io/fastR2/
BugReports: https://github.com/rpruim/fastR2/issues
NeedsCompilation: no
Packaged: 2025-07-30 16:12:02 UTC; rpruim
Author: Randall Pruim [aut, cre]
Maintainer: Randall Pruim <rpruim@calvin.edu>
Repository: CRAN
Date/Publication: 2025-07-30 16:30:15 UTC
Built: R 4.6.0; ; 2026-04-30 23:23:13 UTC; unix
