# Generated by roxygen2: do not edit by hand

S3method(information,maxLik)
S3method(plot,maxLik2)
S3method(summary,nlmax)
S3method(summary,nlmin)
S3method(vaov,formula)
export(SSplot)
export(col.fastR)
export(col.perc)
export(funvec)
export(geolm)
export(givenOrder)
export(grid.identify.points)
export(information)
export(maxLik2)
export(nlmax)
export(nlmin)
export(row.perc)
export(snippet)
export(tdf)
export(to2d)
export(vaov)
export(wald.ci)
export(wilson.ci)
import(mosaic)
importFrom(dplyr,tibble)
importFrom(ggplot2,aes)
importFrom(ggplot2,geom_hline)
importFrom(ggplot2,geom_vline)
importFrom(ggplot2,ggplot)
importFrom(ggplot2,labs)
importFrom(ggplot2,stat_function)
importFrom(grDevices,colorRampPalette)
importFrom(grDevices,gray)
importFrom(grDevices,heat.colors)
importFrom(grid,gpar)
importFrom(grid,grid.text)
importFrom(grid,unit)
importFrom(lattice,cloud)
importFrom(lattice,latticeParseFormula)
importFrom(lattice,levelplot)
importFrom(lattice,trellis.par.set)
importFrom(lattice,xyplot)
importFrom(maxLik,maxLik)
importFrom(miscTools,stdEr)
importFrom(numDeriv,grad)
importFrom(stats,coef)
importFrom(stats,df)
importFrom(stats,effects)
importFrom(stats,lm)
importFrom(stats,nlm)
importFrom(stats,qnorm)
importFrom(utils,file_test)
importFrom(utils,head)
