## z_test <-
##   function (x, alternative = c("two.sided", "less", "greater"),
##             mu = 0, sigma = 1, conf.level = 0.95)
##   {
##     DNAME <- deparse(substitute(x))      # record name of data coming in
##     alternative <- match.arg(alternative)      # fancy argument matching
## 
##     # your code goes here			
##   }

