(choose(13, 1) *            # a number to have three of
 choose( 4, 3) *            # three of that number
 choose(12, 1) *            # a different number to have two of
 choose( 4, 2)) /           # two of that number
   choose(52, 5)

