## gf_boxplot(Sepal.Length ~ Species, data = iris)
## gf_boxplot(Sepal.Length ~ Species, data = iris) %>%
##   gf_refine(coord_flip())
## gf_boxplot(duration ~ "", data = MASS::geyser) %>%
##   gf_refine(coord_flip())

