gf_histogram( ~ Sepal.Length, data = iris, 
    breaks = c(4, 5, 5.5, 6, 6.5, 7, 8, 10), 
    color = "black", fill = "skyblue")
gf_dhistogram( ~ Sepal.Length, data = iris, 
    breaks = c(4, 5, 5.5, 6, 6.5, 7, 8, 10), 
    color = "black", fill = "skyblue")

