as.numeric(u)                    # creates nameless version
u                                # but doesn't change its input
names(u) <- NULL                 # this removes the names from u
u                                # no more names

